==> eslint-config-javascript-0.4.0.tgz: package/rules/imports.js <==
const OFF   = 0;    // OFF   or 0 - turn the rule off
const WARN  = 1;    // WARN  or 1 - turn the rule on as a warning (does not affect exit code)
const ERROR = 2;    // ERROR or 2 - turn the rule on as an error (exit code will be 1)


module.exports = {
  env: {
    es6: true
  },
  parserOptions: {
    ecmaVersion: '2015',
    sourceType: 'module'
  },
  plugins: [
    'import'
  ],
  settings: {
    'import/resolver': {
      node: {
        extensions: ['.mjs', '.js', '.json']
      }
    },
    'import/extensions': ['.js', '.mjs', '.jsx'],
    'import/core-modules': [],
    'import/ignore': [
      'node_modules',
      '\\.(coffee|scss|css|less|hbs|svg|json)$'
    ]
  },

  rules: {
    /*
     * Static analysis
     */

    // enforce imports point to files/modules that can be resolved
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-unresolved.md
    'import/no-unresolved': [ERROR, {
      commonjs: true,
      amd: false,
      caseSensitive: true
    }],

    // enforce named imports coupled with named exports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/named.md
    'import/named': ERROR,

    // enforce default import coupled with default export
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/default.md
    'import/default': WARN,

    // enforce names exist at the time they are dereferenced, when imported as a full namespace
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/namespace.md
    'import/namespace': [ERROR, {
      allowComputed: false
    }],


    /*
     * Helpful warnings
     */

    // disallow invalid exports, e.g. multiple defaults
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/export.md
    'import/export': ERROR,

    // disallow a default import name to match a named export
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-named-as-default.md
    'import/no-named-as-default': ERROR,

    // disallow default export property names that are also named exports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-named-as-default-member.md
    'import/no-named-as-default-member': ERROR,

    // disallow use of jsdoc-marked-DEPRECATED imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-deprecated.md
    'import/no-deprecated': OFF,

    // disallow the use of extraneous packages
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-extraneous-dependencies.md
    // paths are treated both as absolute paths, and relative to process.cwd()
    'import/no-extraneous-dependencies': [ERROR, {
      devDependencies: [
        'test/**',                        // tape, common npm pattern
        'tests/**',                       // also common npm pattern
        'spec/**',                        // mocha, rspec-like pattern
        '**/__tests__/**',                // jest pattern
        '**/__mocks__/**',                // jest pattern
        'test.{js,jsx}',                  // repos with a single test file
        'test-*.{js,jsx}',                // repos with multiple top-level test files
        '**/*{.,_}{test,spec}.{js,jsx}',  // tests where the extension or filename suffix denotes that it is a test
        '**/jest.config.js',              // jest config
        '**/jest.setup.js',               // jest setup
        '**/vue.config.js',               // vue-cli config
        '.webpack/**',                    // webpack config
        '**/webpack.config.js',           // webpack config
        '**/webpack.config.*.js',         // webpack config
        '**/rollup.config.js',            // rollup config
        '**/rollup.config.*.js',          // rollup config
        '**/gulpfile.js',                 // gulp config
        '**/gulpfile.*.js',               // gulp config
        '**/Gruntfile{,.js}',             // grunt config
        '**/protractor.conf.js',          // protractor config
        '**/protractor.conf.*.js',        // protractor config
        '**/karma.conf.js',               // karma config
        '**/.eslintrc.js'                 // eslint config
      ],
      optionalDependencies: false
    }],

    // disallow mutable exports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-mutable-exports.md
    'import/no-mutable-exports': ERROR,


    /*
     * Module systems
     */

    // disallow require()
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-commonjs.md
    'import/no-commonjs': OFF,

    // disallow AMD require/define
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-amd.md
    'import/no-amd': ERROR,

    // no Node.js builtin modules
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-nodejs-modules.md
    'import/no-nodejs-modules': OFF,


    /*
     * Style guide
     */

    // USE import/order
    // disallow non-import statements appearing before import statements
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/first.md
    'import/first': OFF,

    // DEPRECATED in favor of `import/first`
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/imports-first.md
    'import/imports-first': OFF,

    // disallow duplicate imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-duplicates.md
    'import/no-duplicates': ERROR,

    // disallow namespace imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-namespace.md
    'import/no-namespace': WARN,

    // enforce consistent use of file extension within the import path
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/extensions.md
    'import/extensions': [ERROR, 'ignorePackages', {
      js: 'never',
      jsx: 'never',
      ts: 'never',
      tsx: 'never',
      mjs: 'never'
    }],

    // enforce absolute imports are above relative imports and that unassigned imports are ignored
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/order.md
    'import/order': [ERROR, {
      groups: [
        ['builtin', 'external', 'internal', 'sibling', 'index', 'object']
      ],
      alphabetize: {
        order: 'asc',
        caseInsensitive: false
      },
      warnOnUnassignedImports: true
    }],

    // require a newline after the last import/require in a group
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/newline-after-import.md
    'import/newline-after-import': [ERROR, {
      count: 2
    }],

    // require modules with a single export to use a default export
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/prefer-default-export.md
    'import/prefer-default-export': ERROR,

    // enforce which files can be imported in a given folder
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-restricted-paths.md
    'import/no-restricted-paths': OFF,

    // disallow modules to have too many dependencies
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/max-dependencies.md
    'import/max-dependencies': [WARN, {
      max: 10
    }],

    // disallow import of modules using absolute paths
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-absolute-path.md
    'import/no-absolute-path': [ERROR, {
      esmodule: true,
      commonjs: true,
      amd: false
    }],

    // disallow require() calls with expressions
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-dynamic-require.md
    'import/no-dynamic-require': ERROR,

    // prevent importing the submodules of other modules
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-internal-modules.md
    'import/no-internal-modules': [OFF, {
      allow: []
    }],

    // warn if a module could be mistakenly parsed as a script by a consumer leveraging Unambiguous JavaScript Grammar
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/unambiguous.md
    'import/unambiguous': WARN,

    // disallow Webpack loader syntax in imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-webpack-loader-syntax.md
    'import/no-webpack-loader-syntax': ERROR,

    // prevent unassigned imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-unassigned-import.md
    'import/no-unassigned-import': [ERROR, {
      allow: ['**/*.css']
    }],

    // prevent importing the default as if it were named
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-named-default.md
    'import/no-named-default': ERROR,

    // prevent a module's default export as unnamed
    // https://github.com/benmosher/eslint-plugin-import/blob/d9b712ac7fd1fddc391f7b234827925c160d956f/docs/rules/no-anonymous-default-export.md
    'import/no-anonymous-default-export': [ERROR, {
      allowArray: false,
      allowArrowFunction: false,
      allowAnonymousClass: false,
      allowAnonymousFunction: false,
      allowLiteral: false,
      allowObject: false
    }],

    // enforce all exports are declared at the bottom of the file.
    // https://github.com/benmosher/eslint-plugin-import/blob/98acd6afd04dcb6920b81330114e146dc8532ea4/docs/rules/exports-last.md
    'import/exports-last': ERROR,

    // enforce grouping of named exports in a single export declaration
    // https://github.com/benmosher/eslint-plugin-import/blob/44a038c06487964394b1e15b64f3bd34e5d40cde/docs/rules/group-exports.md
    'import/group-exports': ERROR,

    // disallow default exports (inverse of prefer-default-export)
    // https://github.com/benmosher/eslint-plugin-import/blob/44a038c06487964394b1e15b64f3bd34e5d40cde/docs/rules/no-default-export.md
    'import/no-default-export': OFF,

    // disallow named exports (inverse of no-default-export)
    // https://github.com/benmosher/eslint-plugin-import/blob/1ec80fa35fa1819e2d35a70e68fb6a149fb57c5e/docs/rules/no-named-export.md
    'import/no-named-export': OFF,

    // disallow a module from importing itself
    // https://github.com/benmosher/eslint-plugin-import/blob/44a038c06487964394b1e15b64f3bd34e5d40cde/docs/rules/no-self-import.md
    'import/no-self-import': ERROR,

    // disallow cyclical dependencies between modules
    // https://github.com/benmosher/eslint-plugin-import/blob/d81f48a2506182738409805f5272eff4d77c9348/docs/rules/no-cycle.md
    'import/no-cycle': [ERROR, {
      maxDepth: Infinity
    }],

    // enforces that there are no useless path segments
    // https://github.com/benmosher/eslint-plugin-import/blob/ebafcbf59ec9f653b2ac2a0156ca3bcba0a7cf57/docs/rules/no-useless-path-segments.md
    'import/no-useless-path-segments': ERROR,

    // require a leading comment with a webpackChunkName for dynamic imports
    // https://github.com/benmosher/eslint-plugin-import/blob/ebafcbf59ec9f653b2ac2a0156ca3bcba0a7cf57/docs/rules/dynamic-import-chunkname.md
    'import/dynamic-import-chunkname': [WARN, {
      importFunctions: [],
      webpackChunknameFormat: '[0-9a-zA-Z-_/.]+'
    }],

    // prevent imports to folders in relative parent paths
    // https://github.com/benmosher/eslint-plugin-import/blob/c34f14f67f077acd5a61b3da9c0b0de298d20059/docs/rules/no-relative-parent-imports.md
    'import/no-relative-parent-imports': WARN,

    // prevent modules without any exports, or with unused exports
    // https://github.com/benmosher/eslint-plugin-import/blob/f63dd261809de6883b13b6b5b960e6d7f42a7813/docs/rules/no-unused-modules.md
    'import/no-unused-modules': [OFF, {
      // ignoreExports: [],
      missingExports: true,
      unusedExports: true
    }],

    // disallow import declarations with CommonJS exports in any module except for the main module
    // https://github.com/benmosher/eslint-plugin-import/blob/1012eb951767279ce3b540a4ec4f29236104bb5b/docs/rules/no-import-module-exports.md
    'import/no-import-module-exports': [ERROR, {
      exceptions: []
    }],

    // prevent importing packages through relative paths
    // https://github.com/benmosher/eslint-plugin-import/blob/1012eb951767279ce3b540a4ec4f29236104bb5b/docs/rules/no-relative-packages.md
    'import/no-relative-packages': ERROR
  }
};

==> eslint-config-javascript-0.5.0.tgz: package/rules/imports.js <==
const OFF   = 0;    // OFF   or 0 - turn the rule off
const WARN  = 1;    // WARN  or 1 - turn the rule on as a warning (does not affect exit code)
const ERROR = 2;    // ERROR or 2 - turn the rule on as an error (exit code will be 1)


module.exports = {
  env: {
    es6: true
  },
  parserOptions: {
    ecmaVersion: '2015',
    sourceType: 'module'
  },
  plugins: [
    'import'
  ],
  settings: {
    'import/resolver': {
      node: {
        extensions: ['.mjs', '.js', '.json']
      }
    },
    'import/extensions': ['.js', '.mjs', '.jsx'],
    'import/core-modules': [],
    'import/ignore': [
      'node_modules',
      '\\.(coffee|scss|css|less|hbs|svg|json)$'
    ]
  },

  rules: {
    /*
     * Static analysis
     */

    // enforce imports point to files/modules that can be resolved
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-unresolved.md
    'import/no-unresolved': [ERROR, {
      commonjs: true,
      amd: false,
      caseSensitive: true
    }],

    // enforce named imports coupled with named exports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/named.md
    'import/named': ERROR,

    // enforce default import coupled with default export
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/default.md
    'import/default': WARN,

    // enforce names exist at the time they are dereferenced, when imported as a full namespace
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/namespace.md
    'import/namespace': [ERROR, {
      allowComputed: false
    }],


    /*
     * Helpful warnings
     */

    // disallow invalid exports, e.g. multiple defaults
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/export.md
    'import/export': ERROR,

    // disallow a default import name to match a named export
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-named-as-default.md
    'import/no-named-as-default': ERROR,

    // disallow default export property names that are also named exports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-named-as-default-member.md
    'import/no-named-as-default-member': ERROR,

    // disallow use of jsdoc-marked-DEPRECATED imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-deprecated.md
    'import/no-deprecated': OFF,

    // disallow the use of extraneous packages
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-extraneous-dependencies.md
    // paths are treated both as absolute paths, and relative to process.cwd()
    'import/no-extraneous-dependencies': [ERROR, {
      devDependencies: [
        'test/**',                        // tape, common npm pattern
        'tests/**',                       // also common npm pattern
        'spec/**',                        // mocha, rspec-like pattern
        '**/__tests__/**',                // jest pattern
        '**/__mocks__/**',                // jest pattern
        'test.{js,jsx}',                  // repos with a single test file
        'test-*.{js,jsx}',                // repos with multiple top-level test files
        '**/*{.,_}{test,spec}.{js,jsx}',  // tests where the extension or filename suffix denotes that it is a test
        '**/jest.config.js',              // jest config
        '**/jest.setup.js',               // jest setup
        '**/vue.config.js',               // vue-cli config
        '.webpack/**',                    // webpack config
        '**/webpack.config.js',           // webpack config
        '**/webpack.config.*.js',         // webpack config
        '**/rollup.config.js',            // rollup config
        '**/rollup.config.*.js',          // rollup config
        '**/gulpfile.js',                 // gulp config
        '**/gulpfile.*.js',               // gulp config
        '**/Gruntfile{,.js}',             // grunt config
        '**/protractor.conf.js',          // protractor config
        '**/protractor.conf.*.js',        // protractor config
        '**/karma.conf.js',               // karma config
        '**/.eslintrc.js'                 // eslint config
      ],
      optionalDependencies: false
    }],

    // disallow mutable exports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-mutable-exports.md
    'import/no-mutable-exports': ERROR,


    /*
     * Module systems
     */

    // disallow require()
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-commonjs.md
    'import/no-commonjs': OFF,

    // disallow AMD require/define
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-amd.md
    'import/no-amd': ERROR,

    // no Node.js builtin modules
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-nodejs-modules.md
    'import/no-nodejs-modules': OFF,


    /*
     * Style guide
     */

    // USE import/order
    // disallow non-import statements appearing before import statements
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/first.md
    'import/first': OFF,

    // DEPRECATED in favor of `import/first`
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/imports-first.md
    'import/imports-first': OFF,

    // disallow duplicate imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-duplicates.md
    'import/no-duplicates': ERROR,

    // disallow namespace imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-namespace.md
    'import/no-namespace': WARN,

    // enforce consistent use of file extension within the import path
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/extensions.md
    'import/extensions': [ERROR, 'ignorePackages', {
      js: 'never',
      jsx: 'never',
      ts: 'never',
      tsx: 'never',
      mjs: 'never'
    }],

    // enforce absolute imports are above relative imports and that unassigned imports are ignored
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/order.md
    'import/order': [ERROR, {
      groups: [
        ['builtin', 'external', 'internal', 'sibling', 'parent', 'index', 'object']
      ],
      alphabetize: {
        // order: 'asc',
        caseInsensitive: false
      },
      warnOnUnassignedImports: true
    }],

    // require a newline after the last import/require in a group
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/newline-after-import.md
    'import/newline-after-import': [ERROR, {
      count: 2
    }],

    // require modules with a single export to use a default export
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/prefer-default-export.md
    'import/prefer-default-export': ERROR,

    // enforce which files can be imported in a given folder
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-restricted-paths.md
    'import/no-restricted-paths': OFF,

    // disallow modules to have too many dependencies
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/max-dependencies.md
    'import/max-dependencies': [WARN, {
      max: 10
    }],

    // disallow import of modules using absolute paths
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-absolute-path.md
    'import/no-absolute-path': [ERROR, {
      esmodule: true,
      commonjs: true,
      amd: false
    }],

    // disallow require() calls with expressions
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-dynamic-require.md
    'import/no-dynamic-require': ERROR,

    // prevent importing the submodules of other modules
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-internal-modules.md
    'import/no-internal-modules': [OFF, {
      allow: []
    }],

    // warn if a module could be mistakenly parsed as a script by a consumer leveraging Unambiguous JavaScript Grammar
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/unambiguous.md
    'import/unambiguous': WARN,

    // disallow Webpack loader syntax in imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-webpack-loader-syntax.md
    'import/no-webpack-loader-syntax': ERROR,

    // prevent unassigned imports
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-unassigned-import.md
    'import/no-unassigned-import': [ERROR, {
      allow: ['**/*.css']
    }],

    // prevent importing the default as if it were named
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-named-default.md
    'import/no-named-default': ERROR,

    // prevent a module's default export as unnamed
    // https://github.com/benmosher/eslint-plugin-import/blob/d9b712ac7fd1fddc391f7b234827925c160d956f/docs/rules/no-anonymous-default-export.md
    'import/no-anonymous-default-export': [ERROR, {
      allowArray: false,
      allowArrowFunction: false,
      allowAnonymousClass: false,
      allowAnonymousFunction: false,
      allowLiteral: false,
      allowObject: false
    }],

    // enforce all exports are declared at the bottom of the file.
    // https://github.com/benmosher/eslint-plugin-import/blob/98acd6afd04dcb6920b81330114e146dc8532ea4/docs/rules/exports-last.md
    'import/exports-last': ERROR,

    // enforce grouping of named exports in a single export declaration
    // https://github.com/benmosher/eslint-plugin-import/blob/44a038c06487964394b1e15b64f3bd34e5d40cde/docs/rules/group-exports.md
    'import/group-exports': ERROR,

    // disallow default exports (inverse of prefer-default-export)
    // https://github.com/benmosher/eslint-plugin-import/blob/44a038c06487964394b1e15b64f3bd34e5d40cde/docs/rules/no-default-export.md
    'import/no-default-export': OFF,

    // disallow named exports (inverse of no-default-export)
    // https://github.com/benmosher/eslint-plugin-import/blob/1ec80fa35fa1819e2d35a70e68fb6a149fb57c5e/docs/rules/no-named-export.md
    'import/no-named-export': OFF,

    // disallow a module from importing itself
    // https://github.com/benmosher/eslint-plugin-import/blob/44a038c06487964394b1e15b64f3bd34e5d40cde/docs/rules/no-self-import.md
    'import/no-self-import': ERROR,

    // disallow cyclical dependencies between modules
    // https://github.com/benmosher/eslint-plugin-import/blob/d81f48a2506182738409805f5272eff4d77c9348/docs/rules/no-cycle.md
    'import/no-cycle': [ERROR, {
      maxDepth: Infinity
    }],

    // enforces that there are no useless path segments
    // https://github.com/benmosher/eslint-plugin-import/blob/ebafcbf59ec9f653b2ac2a0156ca3bcba0a7cf57/docs/rules/no-useless-path-segments.md
    'import/no-useless-path-segments': ERROR,

    // require a leading comment with a webpackChunkName for dynamic imports
    // https://github.com/benmosher/eslint-plugin-import/blob/ebafcbf59ec9f653b2ac2a0156ca3bcba0a7cf57/docs/rules/dynamic-import-chunkname.md
    'import/dynamic-import-chunkname': [WARN, {
      importFunctions: [],
      webpackChunknameFormat: '[0-9a-zA-Z-_/.]+'
    }],

    // prevent imports to folders in relative parent paths
    // https://github.com/benmosher/eslint-plugin-import/blob/c34f14f67f077acd5a61b3da9c0b0de298d20059/docs/rules/no-relative-parent-imports.md
    'import/no-relative-parent-imports': WARN,

    // prevent modules without any exports, or with unused exports
    // https://github.com/benmosher/eslint-plugin-import/blob/f63dd261809de6883b13b6b5b960e6d7f42a7813/docs/rules/no-unused-modules.md
    'import/no-unused-modules': [OFF, {
      // ignoreExports: [],
      missingExports: true,
      unusedExports: true
    }],

    // disallow import declarations with CommonJS exports in any module except for the main module
    // https://github.com/benmosher/eslint-plugin-import/blob/1012eb951767279ce3b540a4ec4f29236104bb5b/docs/rules/no-import-module-exports.md
    'import/no-import-module-exports': [ERROR, {
      exceptions: []
    }],

    // prevent importing packages through relative paths
    // https://github.com/benmosher/eslint-plugin-import/blob/1012eb951767279ce3b540a4ec4f29236104bb5b/docs/rules/no-relative-packages.md
    'import/no-relative-packages': ERROR
  }
};
